@@ -31,7 +31,6 @@ CmdSwitch::CmdSwitch(int argc,char *argv[],const char *modname,
 {
   unsigned l=0;
   bool handled=false;
-  bool debug=false;
 
   for(int i=1;i<argc;i++) {
 #ifndef WIN32
@@ -44,9 +43,6 @@ CmdSwitch::CmdSwitch(int argc,char *argv[],const char *modname,
       printf("\n%s %s\n",modname,usage);
       exit(0);
     }
-    if(!strcmp(argv[i],"-d")) {
-      debug=true;
-    }
     l=strlen(argv[i]);
     handled=false;
     for(unsigned j=0;j<l;j++) {
@@ -64,18 +60,6 @@ CmdSwitch::CmdSwitch(int argc,char *argv[],const char *modname,
       switch_processed.push_back(false);
     }
   }
-
-  //
-  // Initialize Logging
-  //
-#ifndef WIN32
-  if(debug) {
-    openlog(modname,LOG_PERROR,LOG_USER);
-  }
-  else {
-    openlog(modname,0,LOG_USER);
-  }
-#endif  // WIN32
 }
 
 
