@@ -24,9 +24,13 @@
 #include <queue>
 #include <vector>
 
-#include <dlfcn.h>
-#include <stdint.h>
+#include <ltdl.h>
+
+#ifndef WIN32
 #include <syslog.h>
+#endif  // WIN32
+
+#include <stdint.h>
 
 #include <samplerate.h>
 
@@ -43,7 +47,7 @@ class Codec : public QObject
 {
   Q_OBJECT;
  public:
-  enum Type {TypeNull=0,TypeMpeg1=1,TypeVorbis=2,TypeAac=3,TypePassthrough=4,
+  enum Type {TypeNull=0,TypeMpeg1=1,TypeOgg=2,TypeAac=3,TypePassthrough=4,
 	     TypeLast=5};
   Codec(Codec::Type type,unsigned bitrate,QObject *parent=0);
   ~Codec();
@@ -62,6 +66,8 @@ class Codec : public QObject
   virtual void getStats(QStringList *hdrs,QStringList *values,bool is_first);
   virtual bool isAvailable() const=0;
   virtual QString defaultExtension() const=0;
+  static void interleave(float *pcm_out,float **pcm_in,
+			 unsigned chans,unsigned frames);
   static bool acceptsContentType(Type type,const QString &mimetype);
   static bool acceptsFormatIdentifier(Type type,const QString &fmt_id);
   static bool acceptsExtension(Type type,const QString &ext);
@@ -85,7 +91,7 @@ class Codec : public QObject
   virtual void loadStats(QStringList *hdrs,QStringList *values,bool is_first)=0;
 
  private:
-  uint64_t codec_bytes_processed;
+  long unsigned codec_bytes_processed;
   bool codec_bytes_processed_changed;
   uint64_t codec_frames_generated;
   std::queue<uint64_t> codec_metadata_bytes;
