@@ -67,6 +67,18 @@ Connector::~Connector()
 }
 
 
+QString Connector::postData() const
+{
+  return conn_post_data;
+}
+
+
+void Connector::setPostData(const QString &str)
+{
+  conn_post_data=str;
+}
+
+
 QString Connector::serverUsername() const
 {
   return conn_server_username;
@@ -301,6 +313,10 @@ QString Connector::serverTypeText(Connector::ServerType type)
     ret=tr("File");
     break;
 
+  case Connector::SignalGenerator:
+    ret=tr("Signal Generator");
+    break;
+
   case Connector::LastServer:
     break;
   }
@@ -326,6 +342,10 @@ QString Connector::optionKeyword(Connector::ServerType type)
     ret="file";
     break;
 
+  case Connector::SignalGenerator:
+    ret="tone";
+    break;
+
   case Connector::LastServer:
     break;
   }
@@ -363,6 +383,10 @@ bool Connector:: acceptsContentType(Connector::ServerType type,
   case Connector::FileServer:   // ServerId handles it.
     break;
 
+  case Connector::SignalGenerator:  // Doesn't use the mimetype at all
+    ret=true;
+    break;
+
   case Connector::LastServer:
     break;
   }
