@@ -21,31 +21,44 @@
 #include "dev_alsa.h"
 #include "dev_file.h"
 #include "dev_jack.h"
+#include "dev_mme.h"
 #include "dev_stdout.h"
+
 #include "audiodevicefactory.h"
 
-AudioDevice *AudioDeviceFactory(AudioDevice::Type type,Codec *codec,QObject *parent)
+AudioDevice *AudioDeviceFactory(AudioDevice::Type type,unsigned pregap,
+				Codec *codec,QObject *parent)
 {
   AudioDevice *audiodevice=NULL;
 
   switch(type) {
   case AudioDevice::Stdout:
-    audiodevice=new DevStdout(codec,parent);
+    audiodevice=new DevStdout(pregap,codec,parent);
     break;
 
   case AudioDevice::Alsa:
-    audiodevice=new DevAlsa(codec,parent);
+#ifdef ALSA
+    audiodevice=new DevAlsa(pregap,codec,parent);
+#endif  // ALSA
     break;
  
   case AudioDevice::AsiHpi:
     break;
 
   case AudioDevice::File:
-    audiodevice=new DevFile(codec,parent);
+    audiodevice=new DevFile(pregap,codec,parent);
     break;
 
   case AudioDevice::Jack:
-    audiodevice=new DevJack(codec,parent);
+#ifdef JACK
+    audiodevice=new DevJack(pregap,codec,parent);
+#endif  // JACK
+    break;
+
+  case AudioDevice::Mme:
+#ifdef MME
+    audiodevice=new DevMme(pregap,codec,parent);
+#endif  // MME
     break;
 
   case AudioDevice::LastType:
